==> react-native-wifi-and-hotspot-wizard-1.0.4-stable.tgz: package/README.md <==
<p align="center"> <img width="70%" alt="Cover of React Native Wifi And Hotspot Wizard" src="https://res.cloudinary.com/prafulla98/image/upload/v1593954792/React%20Native%20Wifi%20and%20Hotspot%20Wizard/logo_fxmvs1.gif"/> </p>
<meta name="og:image" >
<p align="center">
<a href="CONTRIBUTING.md"><img src="https://img.shields.io/badge/Contributions-Welcome-blueviolet?style=for-the-badge&logo=github&logoColor=white&labelColor=black" alt="Contributions"/></a>
<a href="https://join.slack.com/t/wifihotspotwizard/shared_invite/zt-f2mmp8p3-EIlxb~FOlNd3FaCgP6UZkQ"><img src="https://img.shields.io/badge/SLACK-JOIN%20SLACK-blueviolet?logo=Slack&labelColor=black&style=for-the-badge" alt="Slack"/></a>
<img src="https://img.shields.io/badge/ANDROID-SUPPORTED-brightgreen?style=for-the-badge&logo=android&labelColor=black" alt="android"/>
<a href="https://www.npmjs.com/package/react-native-wifi-and-hotspot-wizard"><img src="https://img.shields.io/npm/v/react-native-wifi-and-hotspot-wizard?color=%23C33F14&logo=npm&style=for-the-badge&labelColor=black" alt="npm"></a>
<a href="https://www.npmjs.com/package/react-native-wifi-and-hotspot-wizard"><img src="https://img.shields.io/npm/dt/react-native-wifi-and-hotspot-wizard?color=brightgreen&logo=npm&style=for-the-badge&labelColor=black" alt="Downloads"></a>
</p>
<pre align="center">   <img 
width="30%"     src="https://res.cloudinary.com/prafulla98/image/upload/v1593957755/React%20Native%20Wifi%20and%20Hotspot%20Wizard/connectToNetwork_oflsox.gif"></a>        <img 
width="30%"     src="https://res.cloudinary.com/prafulla98/image/upload/v1593957741/React%20Native%20Wifi%20and%20Hotspot%20Wizard/getNearbyNetworks_j2o3pw.gif"></a> 
</pre>

 ⚙️ Configure both **Wifi and Hotspot** settings using a single library. 

  This library also **automatically deals with run-time permission management**.


## Getting Started

Install The Library Using NPM

```sh
npm install react-native-wifi-and-hotspot-wizard
```

Link The Library

```sh
react-native link react-native-wifi-and-hotspot-wizard
```

### Usage

```javascript
import {WifiWizard, HotspotWizard} from 'react-native-wifi-and-hotspot-wizard';

// example 
WifiWizard.turnOnWifi(); // turns on wifi
HotspotWizard.turnOffhotspot(); // turns off hotspot
```

**Refer Official Documentation for detailed usage of all the methods :-**

<a href="https://react-native-wifi-and-hotspot-wizard.netlify.app" target="_blank">
<img 
height="100"     src="https://res.cloudinary.com/prafulla98/image/upload/v1592631858/React%20Native%20Wifi%20and%20Hotspot%20Wizard/Frame_4get_started_button_fvscwx.png"></a>

## 📱 Test Library 

To checkout this library before using it you can install 
[WifiAndHotspotWizardDemo.apk](https://github.com/Pika1998/react-native-wifi-and-hotspot-wizard/WifiAndHotspotWizardDemo.apk)

You can also find the code for Example Application over [Here](https://github.com/Pika1998/react-native-wifi-and-hotspot-wizard/tree/master/ExampleApplication)

<img 
width="30%"     src="https://res.cloudinary.com/prafulla98/image/upload/v1593955056/React%20Native%20Wifi%20and%20Hotspot%20Wizard/screenshot1_1_ggi2wh.png"></a>
<img 
width="30%"     src="https://res.cloudinary.com/prafulla98/image/upload/v1593955602/React%20Native%20Wifi%20and%20Hotspot%20Wizard/Screenshot_2020-07-05-18-51-13-836_com_qfsy5v.png"></a> 
<img 
width="30%"     src="https://res.cloudinary.com/prafulla98/image/upload/v1593955605/React%20Native%20Wifi%20and%20Hotspot%20Wizard/Screenshot_2020-07-05-18-50-57-816_com_tq5koi.png"></a>



## 😎 CONTRIBUTE

Feel free to contribute to this library, any small addition to this is very much appreciated and welcomed :)


Checkout the [CONTRIBUTION Guidelines](CONTRIBUTION.md) to get started. 

You can start by checking out some of the [Issues](https://github.com/Pika1998/react-native-wifi-and-hotspot-wizard/issues) in the application.

## ⏱️ CHANGELOG

You can find all the changes made to this library in [CHANGELOG.md](CHANGELOG.md)

==> react-native-wifi-and-hotspot-wizard-1.0.5-stable.tgz: package/README.md <==
<p align="center"> <img width="70%" alt="Cover of React Native Wifi And Hotspot Wizard" src="https://res.cloudinary.com/prafulla98/image/upload/v1593954792/React%20Native%20Wifi%20and%20Hotspot%20Wizard/logo_fxmvs1.gif"/> </p>
<meta name="twitter:card" content="summary_large_image">
<p align="center">
<a href="CONTRIBUTING.md"><img src="https://img.shields.io/badge/Contributions-Welcome-blueviolet?style=for-the-badge&logo=github&logoColor=white&labelColor=black" alt="Contributions"/></a>
<a href="https://join.slack.com/t/wifihotspotwizard/shared_invite/zt-f2mmp8p3-EIlxb~FOlNd3FaCgP6UZkQ"><img src="https://img.shields.io/badge/SLACK-JOIN%20SLACK-blueviolet?logo=Slack&labelColor=black&style=for-the-badge" alt="Slack"/></a>
<img src="https://img.shields.io/badge/ANDROID-SUPPORTED-brightgreen?style=for-the-badge&logo=android&labelColor=black" alt="android"/>
<a href="https://www.npmjs.com/package/react-native-wifi-and-hotspot-wizard"><img src="https://img.shields.io/npm/v/react-native-wifi-and-hotspot-wizard?color=%23C33F14&logo=npm&style=for-the-badge&labelColor=black" alt="npm"></a>
<a href="https://www.npmjs.com/package/react-native-wifi-and-hotspot-wizard"><img src="https://img.shields.io/npm/dt/react-native-wifi-and-hotspot-wizard?color=brightgreen&logo=npm&style=for-the-badge&labelColor=black" alt="Downloads"></a>
</p>
<pre align="center">   <img 
width="30%"     src="https://res.cloudinary.com/prafulla98/image/upload/v1593957755/React%20Native%20Wifi%20and%20Hotspot%20Wizard/connectToNetwork_oflsox.gif"></a>        <img 
width="30%"     src="https://res.cloudinary.com/prafulla98/image/upload/v1593957741/React%20Native%20Wifi%20and%20Hotspot%20Wizard/getNearbyNetworks_j2o3pw.gif"></a> 
</pre>

 ⚙️ Configure both **Wifi and Hotspot** settings using a single library. 

  This library also **automatically deals with run-time permission management**.


## Getting Started

Install The Library Using NPM

```sh
npm install react-native-wifi-and-hotspot-wizard
```

Link The Library

```sh
react-native link react-native-wifi-and-hotspot-wizard
```

### Usage

```javascript
import {WifiWizard, HotspotWizard} from 'react-native-wifi-and-hotspot-wizard';

// example 
WifiWizard.turnOnWifi(); // turns on wifi
HotspotWizard.turnOffhotspot(); // turns off hotspot
```

**Refer Official Documentation for detailed usage of all the methods :-**

<a href="https://react-native-wifi-and-hotspot-wizard.netlify.app" target="_blank">
<img 
height="100"     src="https://res.cloudinary.com/prafulla98/image/upload/v1592631858/React%20Native%20Wifi%20and%20Hotspot%20Wizard/Frame_4get_started_button_fvscwx.png"></a>

## 📱 Test Library 

To checkout this library before using it you can install 
[WifiAndHotspotWizardDemo.apk](https://github.com/Pika1998/react-native-wifi-and-hotspot-wizard/blob/master/WifiAndHotspotWizardDemo.apk)

You can also find the code for Example Application over [Here](https://github.com/Pika1998/react-native-wifi-and-hotspot-wizard/tree/master/ExampleApplication)

<img 
width="30%"     src="https://res.cloudinary.com/prafulla98/image/upload/v1593955056/React%20Native%20Wifi%20and%20Hotspot%20Wizard/screenshot1_1_ggi2wh.png"></a>
<img 
width="30%"     src="https://res.cloudinary.com/prafulla98/image/upload/v1593955602/React%20Native%20Wifi%20and%20Hotspot%20Wizard/Screenshot_2020-07-05-18-51-13-836_com_qfsy5v.png"></a> 
<img 
width="30%"     src="https://res.cloudinary.com/prafulla98/image/upload/v1593955605/React%20Native%20Wifi%20and%20Hotspot%20Wizard/Screenshot_2020-07-05-18-50-57-816_com_tq5koi.png"></a>


## ⏱️ CHANGELOG

You can find all the changes made to this library in [CHANGELOG.md](CHANGELOG.md)

## 😎 CONTRIBUTE

Feel free to contribute to this library, any small addition to this is very much appreciated and welcomed :)


Checkout the [CONTRIBUTION Guidelines](CONTRIBUTION.md) to get started. 

You can start by checking out some of the [Issues](https://github.com/Pika1998/react-native-wifi-and-hotspot-wizard/issues) in the application.




---

<a href="https://www.buymeacoffee.com/prafulla98" target="_blank"><img height="51" width="217" src="https://cdn.buymeacoffee.com/buttons/default-yellow.png" alt="Buy Me A Coffee" style="height: 51px !important;width: 217px !important;border-radius:10px" ></a>
